import styles from "./card.module.css";
import Image from "next/image";
import Link from "next/link";
import Icons from "../icons/page";
import PropTypes from "prop-types";

const Card = ({
  mainTitle,
  description,
  imageUrl,
  postedOn,
  author,
  readingTime,
}) => {
  return (
    <div className={styles.card}>
      <Link prefetch={false} href="#">
        <Image className={styles.img} src={imageUrl} alt="cardimage" />
      </Link>
      <div className={styles["card-content"]}>
        <Link prefetch={false} href="#" className={styles.title}>
          {mainTitle}
        </Link>
        <p className={styles.description}>{description}</p>
        <div className={styles.cardbottom}>
          <Image
            className={styles.img}
            src={author.authImg}
            quality={100}
            alt="authorImg"
          />
          <div>
            <h3>{author.name}</h3>
            <div className={styles["author-desc"]}>
              {postedOn}
              <span className={styles.icon}>
                <Icons name="clock" />
                {readingTime}
              </span>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};
Card.propTypes = {
  mainTitle: PropTypes.string,
  description: PropTypes.string,
  imageUrl: PropTypes.object,
  postedOn: PropTypes.string,
  author: PropTypes.shape({
    name: PropTypes.string,
    authImg: PropTypes.string, // Use PropTypes.string for authImg
  }),
  postedOn: PropTypes.string,
  readingTime: PropTypes.string,
};

export default Card;
